@@ -36,10 +36,13 @@ package com.google.refine.expr.functions;
 import java.time.OffsetDateTime;
 import java.time.format.DateTimeFormatter;
 import java.util.Properties;
+import java.util.UnknownFormatConversionException;
 
 import com.google.refine.expr.EvalError;
 import com.google.refine.grel.ControlFunctionRegistry;
+import com.google.refine.grel.EvalErrorMessage;
 import com.google.refine.grel.Function;
+import com.google.refine.grel.FunctionDescription;
 import com.google.refine.util.StringUtils;
 
 public class ToString implements Function {
@@ -51,33 +54,37 @@ public class ToString implements Function {
             if (args.length == 2 && args[1] instanceof String) {
                 Object o2 = args[1];
                 if (o1 instanceof OffsetDateTime) {
-                    OffsetDateTime odt = (OffsetDateTime)o1;
-                    return odt.format(DateTimeFormatter.ofPattern((String)o2));
+                    OffsetDateTime odt = (OffsetDateTime) o1;
+                    return odt.format(DateTimeFormatter.ofPattern((String) o2));
                 } else if (o1 instanceof Number) {
-                    return String.format((String) o2, (Number) o1);
+                    try {
+                        return String.format((String) o2, o1);
+                    } catch (UnknownFormatConversionException e) {
+                        return new EvalError(EvalErrorMessage.unknown_format_conversion(e.getMessage()));
+                    }
                 }
             } else if (args.length == 1) {
                 if (o1 instanceof String) {
                     return (String) o1;
                 } else {
                     return StringUtils.toString(o1);
-                } 
+                }
             }
         }
-        return new EvalError(ControlFunctionRegistry.getFunctionName(this) + " accepts an object and an optional second argument containing a Date or Number format string");
+        // second argument containing a Date or Number format string");
+        return new EvalError(EvalErrorMessage.fun_to_string(ControlFunctionRegistry.getFunctionName(this)));
     }
 
-    
     @Override
     public String getDescription() {
-        return "Takes any value type (string, number, date, boolean, error, null) and gives a string version of that value. You can convert numbers to strings with rounding, using an optional string format. See https://docs.oracle.com/javase/8/docs/api/java/util/Formatter.html. You can also convert dates to strings using date parsing syntax. See https://docs.openrefine.org/manual/grelfunctions/#date-functions.";
+        return FunctionDescription.fun_to_string();
     }
-    
+
     @Override
     public String getParams() {
         return "object o, string format (optional)";
     }
-    
+
     @Override
     public String getReturns() {
         return "string";
