@@ -39,7 +39,7 @@ class ListFacet extends Facet {
       this._options.sort = "name";
     }
 
-    this._selection = selection || [];
+    this._selection = selection || config.selection || [];
 
     if (!("invert" in this._config)) {
       this._config.invert = false;
@@ -160,7 +160,7 @@ class ListFacet extends Facet {
       '<div class="facet-controls" bind="controlsDiv" style="display:none;">' +
         '<a bind="choiceCountContainer" class="action" href="javascript:{}"></a> ' +
         '<span class="facet-controls-sortControls" bind="sortGroup">'+$.i18n('core-facets/sort-by')+': ' +
-          '<a href="javascript:{}" bind="sortByNameLink">'+$.i18n('core-facets/name')+'</a>' +
+          '<a href="javascript:{}" bind="sortByNameLink">'+$.i18n('core-facets/name')+'</a> ' +
           '<a href="javascript:{}" bind="sortByCountLink">'+$.i18n('core-facets/count')+'</a>' +
         '</span>' +
         '<button bind="clusterLink" class="facet-controls-button button">'+$.i18n('core-facets/cluster')+'</button>' +
@@ -610,6 +610,8 @@ class ListFacet extends Facet {
     .trigger('select')
     .trigger('focus');
 
+    setInitialHeightTextArea(elmts.textarea[0]);
+
     elmts.cancelButton.on('click',function() {
       MenuSystem.dismissAll();
     });
